# apigo

<div align="center">

[![Build status](https://github.com/nidhaloff/apigo/workflows/build/badge.svg?branch=master&event=push)](https://github.com/nidhaloff/apigo/actions?query=workflow%3Abuild)
[![Python Version](https://img.shields.io/pypi/pyversions/apigo.svg)](https://pypi.org/project/apigo/)
[![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/nidhaloff/apigo/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/nidhaloff/apigo/blob/master/.pre-commit-config.yaml)
[![Semantic Versions](https://img.shields.io/badge/%F0%9F%9A%80-semantic%20versions-informational.svg)](https://github.com/nidhaloff/apigo/releases)
[![License](https://img.shields.io/github/license/nidhaloff/apigo)](https://github.com/nidhaloff/apigo/blob/master/LICENSE)

get a fast REST mock server out of the box

</div>

## Installation

```bash
pip install -U apigo
```

or install with `Poetry`

```bash
poetry add apigo
```

Then you can run

```bash
apigo --help
```


## 🛡 License

[![License](https://img.shields.io/github/license/nidhaloff/apigo)](https://github.com/nidhaloff/apigo/blob/master/LICENSE)

This project is licensed under the terms of the `MIT` license. See [LICENSE](https://github.com/nidhaloff/apigo/blob/master/LICENSE) for more details.

## 📃 Citation

```
@misc{apigo,
  author = {nidhaloff},
  title = {get a fast REST mock server out of the box},
  year = {2021},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {\url{https://github.com/nidhaloff/apigo}}
}
```

## Credits

This project was generated with [`python-package-template`](https://github.com/TezRomacH/python-package-template).
